clc;
close all;
clear all;


% Geometric Quanitites (Specific to model)
LengthS = 1.3572; %Length of edge of octant model
AreaS = 1.446697; %Area of one face of octant model [AreaS=(pi/4)*LengthS^2]

% user input
file = 'Sphere_Outer_1000um_Gf0_5.dat';

% open dat files
fid = fopen(file);

% Initialization
i = 0;
numSteps = 0;
numInterphase=0;

% Read data
while ( ~feof(fid) )   
    tline = fgetl(fid);
    i = i+1;
    
    % read until a new node data is reached
    if (regexpi(tline, 'N O D E   O U T P U T')>0)
        
        count_RFx = 0;
        count_RFy = 0;
        count_RFz = 0;
        count_u = 0;
               
        numSteps = numSteps + 1;
        tline = fgetl(fid);
        i = i+1;
               
        for jk=1:1:(numInterphase+1)
            
            % skip lines that do not contain all numbers
            while(isempty(str2num(tline)))
                tline = fgetl(fid);    
                i = i+1;
            end

            % reached X reaction forces
            while(~isempty(str2num(tline)))

                count_RFx = count_RFx+1;

                data_xrf1 = sscanf(tline, '%d %lf %lf %lf', [1,4]);

                tline = fgetl(fid);
                i = i+1;

                xRF1(count_RFx,numSteps)=data_xrf1(2);
                xRF2(count_RFx,numSteps)=data_xrf1(3);
                xRF3(count_RFx,numSteps)=data_xrf1(4);
            end
            % end of X reaction forces
        
        end
        
        for jk=1:1:(numInterphase+1)
            
            % skip lines that do not contain all numbers
            while(isempty(str2num(tline)))
                tline = fgetl(fid);    
                i = i+1;
            end

            % reached Y reaction forces
            while(~isempty(str2num(tline)))

                count_RFy = count_RFy+1;

                data_yrf1 = sscanf(tline, '%d %lf %lf %lf', [1,4]);

                tline = fgetl(fid);
                i = i+1;

                yRF1(count_RFy,numSteps)=data_yrf1(2);
                yRF2(count_RFy,numSteps)=data_yrf1(3);
                yRF3(count_RFy,numSteps)=data_yrf1(4);
            end
            % end of Y reaction forces

        end
        
        for jk=1:1:(numInterphase+1)
            
            % skip lines that do not contain all numbers
            while(isempty(str2num(tline)))
                tline = fgetl(fid);    
                i = i+1;
            end

            % reached Z reaction forces
            while(~isempty(str2num(tline)))

                count_RFz = count_RFz+1;

                data_zrf1 = sscanf(tline, '%d %lf %lf %lf', [1,4]);

                tline = fgetl(fid);
                i = i+1;

                zRF1(count_RFz,numSteps)=data_zrf1(2);
                zRF2(count_RFz,numSteps)=data_zrf1(3);
                zRF3(count_RFz,numSteps)=data_zrf1(4);
            end
            % end of Z reaction forces
       
        end

        for kk=1:1:(numInterphase+1)
            
            % skip lines that do not contain all numbers
            while(isempty(str2num(tline)))
                tline = fgetl(fid);    
                i = i+1;
            end

            % reached nodal displacements
            while(~isempty(str2num(tline)))

                count_u = count_u+1;

                data_u = sscanf(tline, '%d %lf %lf %lf', [1,4]);

                tline = fgetl(fid);
                i = i+1;

                U1(count_u,numSteps)=data_u(2);
                U2(count_u,numSteps)=data_u(3);
                U3(count_u,numSteps)=data_u(4);
                RadU(count_u,numSteps)=sqrt(data_u(2)*data_u(2)+data_u(3)*data_u(3)+data_u(4)*data_u(4));

            end
            % end of nodal displacements
        
        end
               
        disp(['Step Number = ', num2str(numSteps)]);       
        
    end
    
end

xpRF1 = sum(xRF1);
xpRF2 = sum(xRF2);
xpRF3 = sum(xRF3);

E1 = mean(U1)/(LengthS)*100;
E2 = mean(U2)/(LengthS)*100;
E3 = mean(U3)/(LengthS)*100;
Erad = mean(RadU)/(LengthS)*100;

Stress1x = -1*xpRF1/(AreaS);
Stress2x = -1*xpRF2/(AreaS);
Stress3x = -1*xpRF3/(AreaS);

ypRF1 = sum(yRF1);
ypRF2 = sum(yRF2);
ypRF3 = sum(yRF3);

Stress1y = -1*ypRF1/(AreaS);
Stress2y = -1*ypRF2/(AreaS);
Stress3y = -1*ypRF3/(AreaS);

zpRF1 = sum(zRF1);
zpRF2 = sum(zRF2);
zpRF3 = sum(zRF3);

Stress1z = -1*zpRF1/(AreaS);
Stress2z = -1*zpRF2/(AreaS);
Stress3z = -1*zpRF3/(AreaS);

% close dat file
fclose(fid);

disp(['Abaqus file contains ', num2str(i), ' lines']);
disp(['Total number of steps = ', num2str(numSteps)]);

figure(1)
plot(Erad,Stress1x, '-k')
hold on
xlabel('Macroscopic Strain (%)');
ylabel('Macroscopic Stress (MPa)');
xlim([0 0.035]);
ylim([0 12]);
hold off

